<?php
namespace App\Factory;

use Doctrine\DBAL\Connection;

class Order {
    private $connection;

    public function __construct(Connection $connection) {
        $this->connection = $connection;
    }

    public function history($paramsHistory, $isScheduled = false) 
	{
		$consumer = $paramsHistory['CLIENTECONSUMIDOR'];
		$consumerCondition = '';

		if ($consumer !== 'T') {
			$consumerArray = explode(',', $consumer);
			$consumerMap = array_map(function($name) {
				return "COALESCE(TRIM(C.DSCONSUMIDOR), TRIM(CONS.NMCONSUMIDOR)) LIKE '%" . $name . "%'";
			}, $consumerArray);

			$consumerCondition = "AND (" . implode(' OR ', $consumerMap) . ")";
		}
		
		$scheduledConditions = $isScheduled ? "
			AND (
				(
					C.DTHRAGENDADA BETWEEN TO_DATE(:DTINIAGENDADA, 'DD/MM/YYYY HH24:MI:SS') 
					AND TO_DATE(:DTFIMAGENDADA, 'DD/MM/YYYY HH24:MI:SS')
				)
				OR
				(
					'T' = :DTINIAGENDADA
					OR
					'T' = :DTFIMAGENDADA
				)
			)
			AND C.IDSTCOMANDA <> '4'
		" : '';
		
		$sql = "
		SELECT 
		C.CDFILIAL, 
		L.NMLOJA AS CDLOJA, 
		V.NRVENDAREST,	
		REPLACE(
			(
			(
				CASE TO_CHAR(IDORIGEMPEDFOS) 
				WHEN 'S' 
					THEN C.DSCOMANDA 
				ELSE C.NRCOMANDA END)
			), 
			'DLV_', 
			''
		) 
		AS NRCOMANDA,
		NVL(V.NRVENDARESTAUX, V.NRVENDAREST) AS NRPEDCENTRAL,
		NVL(C.NRCOMANDAEXT,  'N/E')          AS NRCOMANDAEXT,
		NVL(C.IDORGCMDVENDA, 'DLV_OUT')    	 AS IDORGCMDVENDA,
		NVL(C.DSAREAATEND,   'N/A')        	 AS DSAREAATEND,
		IDSINCMSDE,
		IT.QTDPROD,
		DECODE(C.DTHRAGENDADA, null, 'Não', 'Sim') AGENDADO,
		C.IDSTCOMANDA,
		C.VRACRCOMANDA,
		C.IDSTCOMANDA AS STATUS,
		NVL(IT.VRDESCOMANDA, 0) AS VRDESCOMANDA,
		C.DSDESCMOTIV,
		C.DSREFENDCONSCOM,
		C.DSOBSCOMANDA,
		VD.NMRAZSOCVEN,					
		CONS.DSEMAILCONS,
		CONS.CDCONSUMIDOR || ' - ' || CONS.NMCONSUMIDOR AS LABELCONSUMIDOR,
		CONS.CDCLIENTE,
		F.CDFILIAL || ' - ' || F.NMFILIAL AS FILIAL,
		CLI.CDCLIENTE || ' - ' || CLI.NMRAZSOCCLIE AS CLIENTE,
		VD.CDOPERADOR,
		TO_CHAR(C.DTHRAGENDADA, 'DD/MM/YYYY HH24:MI:SS') AS DTHRAGENDADA,
		TO_CHAR(C.DTSAIDACMD, 'DD/MM/YYYY HH24:MI:SS') AS DTSAIDACMD,
		(
			CASE TO_CHAR(C.IDRETBALLOJA)
				WHEN 'S' THEN 'RETIRAR NO BALCÃO'
				WHEN 'N' THEN 'DELIVERY'
				WHEN 'C' THEN 'CONSUMO NO LOCAL'
				ELSE 'OUTROS' END
		) AS TOGO,
		(
			CASE NVL(TO_CHAR(C.DTSAIDACMD), 'NAN')
				WHEN 'NAN' THEN ''
				ELSE VD.NMFANVEN
			END
		) AS NMENTREGADOR,
		COALESCE(C.DSCONSUMIDOR, CONS.NMCONSUMIDOR) NMCONSUMIDOR,
		NVL(C.NRCONTATOCON, CONS.NRTELECONS) NRTELECONS,
		(IT.VRTOTAL + C.VRACRCOMANDA) VRPEDIDO,     
		IT.ACRESCIMO,
		IT.VRTOTALPRODUTOS,
		L.NRTEMPOPRODUCAO AS TEMPOPEDIDO,
		TO_CHAR(V.DTHRABERMESA, 'DD/MM/YYYY HH24:MI:SS') AS DTHRABERMESA			
	
	FROM VENDAREST V
	
	JOIN VENDEDOR VD
		 ON VD.CDVENDEDOR(+) = V.CDVENDEDOR

	JOIN COMANDAVEN C
		 ON V.CDFILIAL    = C.CDFILIAL
		 AND V.NRVENDAREST = C.NRVENDAREST
	
				JOIN FILIAL F
		 ON V.CDFILIAL = F.CDFILIAL
				
	JOIN LOJA L
						 ON L.CDFILIAL = F.CDFILIAL
		 AND L.CDLOJA = C.CDLOJA
	
	JOIN CLIENTE CLI
		 ON V.CDCLIENTE = CLI.CDCLIENTE
	
	JOIN (
			SELECT 
				CONSU.CDCLIENTE||CONSU.CDCONSUMIDOR AS CLIENTECONSUMIDOR, 
				CONSU.CDCLIENTE, 
				CONSU.CDCONSUMIDOR, 
				CONSU.NMCONSUMIDOR,
				CONSU.NRTELECONS, 
				CONSU.DSEMAILCONS, 
				CLI.NMFANTCLIE
			FROM CONSUMIDOR CONSU
			JOIN CLIENTE CLI 
				ON CONSU.CDCLIENTE = CLI.CDCLIENTE
	) CONS
		ON CONS.CDCLIENTE 	 = V.CDCLIENTE
		AND CONS.CDCONSUMIDOR = V.CDCONSUMIDOR              
							
	JOIN (
		SELECT 
			CDFILIAL,
			NRCOMANDA,
			NRVENDAREST, 
			SUM((QTPRODCOMVEN*VRPRECCOMVEN) - VRDESCCOMVEN + VRACRCOMVEN) AS VRTOTAL,
			SUM(VRACRCOMVEN) AS ACRESCIMO,
			SUM(VRDESCCOMVEN) AS VRDESCOMANDA,
			SUM(QTPRODCOMVEN*VRPRECCOMVEN) AS VRTOTALPRODUTOS,
			SUM(QTPRODCOMVEN) AS QTDPROD                                
		FROM ITCOMANDAVEN
		GROUP BY 
			CDFILIAL,
			NRCOMANDA,
			NRVENDAREST
	) IT ON IT.CDFILIAL    = C.CDFILIAL
		AND IT.NRVENDAREST = C.NRVENDAREST
		AND IT.NRCOMANDA   = C.NRCOMANDA

	WHERE
		((INSTR(:CDFILIAL, C.CDFILIAL ) > 0) OR 'T' = :CDFILIAL)
		AND ((INSTR(:NRVENDAREST, C.NRVENDAREST) > 0) OR 'T' = :NRVENDAREST)
		AND ((INSTR(:NRCOMANDA, C.NRCOMANDA) > 0) OR 'T' = :NRCOMANDA)
		AND ((INSTR(:IDSTCOMANDA, C.IDSTCOMANDA) > 0) OR 'T' = :IDSTCOMANDA)
		AND ((INSTR(:IDSINCMSDE, V.IDSINCMSDE) > 0) OR 'T' = :IDSINCMSDE)
		AND ((INSTR(:IDRETBALLOJA, C.IDRETBALLOJA) > 0) OR 'T' = :IDRETBALLOJA)
		AND ((INSTR(:IDORGCMDVENDA, C.IDORGCMDVENDA) > 0) OR 'T' = :IDORGCMDVENDA)
		AND ((INSTR(:IDSINCAGENDA, C.IDSINCAGENDA) > 0) OR 'T' = :IDSINCAGENDA)
		AND (V.DTHRABERMESA BETWEEN TO_DATE(:DTINICABERMESA, 'DD/MM/YYYY HH24:MI:SS') AND TO_DATE(:DTFIMABERMESA, 'DD/MM/YYYY HH24:MI:SS'))
		{$consumerCondition}
		{$scheduledConditions}
		ORDER BY V.DTHRABERMESA DESC
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("DTINICABERMESA", $paramsHistory['DTINICIAL']);
		$stmt->bindValue("DTFIMABERMESA", $paramsHistory['DTFINAL']);
		$stmt->bindValue("CDFILIAL", $paramsHistory['CDFILIAL']);
		$stmt->bindValue("NRVENDAREST", $paramsHistory['NRVENDAREST']);
		$stmt->bindValue("NRCOMANDA", $paramsHistory['NRCOMANDA']);
		$stmt->bindValue("IDSTCOMANDA", $paramsHistory['IDSTCOMANDA']);
		$stmt->bindValue("IDSINCMSDE", $paramsHistory['IDSINCMSDE']);
		$stmt->bindValue("IDRETBALLOJA", $paramsHistory['IDRETBALLOJA']);
		$stmt->bindValue("IDORGCMDVENDA", $paramsHistory['IDORGCMDVENDA']);
		$stmt->bindValue("IDSINCAGENDA", $paramsHistory['IDSINCAGENDA']);

		if ($isScheduled) {
			$stmt->bindValue("DTINIAGENDADA", $paramsHistory['DTINIAGENDADA']);
			$stmt->bindValue("DTFIMAGENDADA", $paramsHistory['DTFIMAGENDADA']);
		}

		$result = $stmt->executeQuery();
    return $result->fetchAllAssociative();
    }

	public function errorLogs($paramsLog) {

		$sql = "
		SELECT 
    COALESCE(F.CDFILIAL, 'N/A') AS CDFILIAL, 
    COALESCE(F.NMFILIAL, 'N/A') AS NMFILIAL, 
    I.NMINTEGRACAO,
    TO_CHAR(E.DTINCLUSAO, 'DD/MM/YYYY HH24:MI:SS') AS DTINCLUSAO, 
    COALESCE(E.DSINTEGRACAOERR, '-') as DSINTEGRACAOERR, 
    E.CDINTEGRACAOERR
	FROM 
    INTEGRACAOERR E
    LEFT JOIN FILIAL F ON E.CDFILIAL = F.CDFILIAL
    JOIN INTEGRACAO I ON E.IDINTEGRACAO = I.CDINTEGRACAO
	WHERE 
    E.IDATIVO = 'S'
    AND ((INSTR(:CDFILIAL, E.CDFILIAL) > 0) OR :CDFILIAL IS NULL)
    AND ((INSTR(:CDINTEGRACAO, I.CDINTEGRACAO) > 0) OR :CDINTEGRACAO IS NULL)
    AND (:STARTDATE IS NULL OR (TRUNC(E.DTINCLUSAO) BETWEEN TO_DATE(:STARTDATE, 'DD/MM/YYYY') AND TO_DATE(:ENDDATE, 'DD/MM/YYYY')))
    AND (
        :SEARCH IS NULL
        OR (
            LOWER(E.CDFILIAL) LIKE LOWER(:SEARCH)
            OR LOWER(F.NMFILIAL) LIKE LOWER(:SEARCH)
            OR LOWER(I.NMINTEGRACAO) LIKE LOWER(:SEARCH)
            OR LOWER(TO_CHAR(E.DTINCLUSAO, 'DD/MM/YYYY HH24:MI:SS')) LIKE LOWER(:SEARCH)
            OR LOWER(E.DSINTEGRACAOERR) LIKE LOWER(:SEARCH)
        )
    )
		 {$paramsLog['order']}
		";
		$stmt = $this->connection->prepare($sql);

		if (!is_null($paramsLog['search'])) {
			$search = $paramsLog['search'];
			$stmt->bindValue("SEARCH", "%$search%");
		}

		$stmt->bindValue("CDFILIAL", $paramsLog['cdFilial']);
		$stmt->bindValue("CDINTEGRACAO",$paramsLog['cdIntegracao']);
		$stmt->bindValue("STARTDATE", $paramsLog['dtInclusao' ][0]);
		$stmt->bindValue("ENDDATE", $paramsLog['dtInclusao' ][1]);
		$result = $stmt->executeQuery();
		return $result->fetchAllAssociative();
	}

	public function deleteOldLogs($deleteLogMonths) 
	{
		$sql = "	
		DELETE
		FROM 
			INTEGRACAOERR
		WHERE DTINCLUSAO NOT BETWEEN (TO_DATE(:DELETEMONTH, 'DD/MM/YYYY HH24:MI:SS')) AND (TO_DATE(:CURRENTDAY, 'DD/MM/YYYY HH24:MI:SS'))
		";
		$stmt = $this->connection->prepare($sql);
		$deleteMonth = mktime(0, 0, 0, date("m")-$deleteLogMonths, date("d"),   date("Y"));
		$deleteMonth = date("d-m-Y H:i:s", $deleteMonth);
		$currentDay = date("d-m-Y H:i:s");
		$stmt->bindValue(":DELETEMONTH", $deleteMonth);
		$stmt->bindValue(":CURRENTDAY", $currentDay);
		$stmt->executeQuery();
	}

	public function updateOldLogs($updateLogMonths)
	{
		$sql = "
			UPDATE INTEGRACAOERR
			SET IDATIVO = 'N'
			WHERE DTINCLUSAO NOT BETWEEN (TO_DATE(:UPDATEMONTH, 'DD/MM/YYYY HH24:MI:SS')) AND (TO_DATE(:CURRENTDAY, 'DD/MM/YYYY HH24:MI:SS'))
		";
		$stmt = $this->connection->prepare($sql);
		$updateMonth = mktime(0, 0, 0, date("m")-$updateLogMonths, date("d"),   date("Y"));
		$updateMonth = date("d-m-Y H:i:s", $updateMonth);
		$currentDay = date("d-m-Y H:i:s");
		$stmt->bindValue(":UPDATEMONTH", $updateMonth);
		$stmt->bindValue(":CURRENTDAY", $currentDay);
		$stmt->executeQuery();
	}

	public function cancelOrder($cdFilial, $nrVendaRest, $nrComanda, $cdOperador, $dsCancMotiv) {
		$sql = "
			UPDATE 
				COMANDAVEN
			SET 
				IDSTCOMANDA  = '4',
				DTHRCANCMD   = TO_DATE(:CURRENTTIME, 'dd/mm/yyyy hh24:mi:ss'),
				CDOPERCANCMD = :CDOPERCANCMD,
				DSCANCMOTIV  = :DSCANCMOTIV

		 	WHERE CDFILIAL    = :CDFILIAL
			  AND NRVENDAREST = :NRVENDAREST
		    AND NRCOMANDA   = :NRCOMANDA
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $cdFilial);
		$stmt->bindValue("NRVENDAREST", $nrVendaRest);
		$stmt->bindValue("NRCOMANDA", $nrComanda);
		$stmt->bindValue("CDOPERCANCMD", $cdOperador);
		$stmt->bindValue("CURRENTTIME", date("d/m/Y H:m:s"));
		$stmt->bindValue("DSCANCMOTIV", $dsCancMotiv);
		$stmt->executeQuery();
	}

	public function getSeller($cdOperador) {
		$sql = "
			SELECT CDVENDEDOR 
			FROM VENDEDOR 
			WHERE CDOPERADOR = :CDOPERADOR
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDOPERADOR", $cdOperador);
		$result = $stmt->executeQuery();
		return $result;
	}

	public function forceOrderSync($cdFilial, $nrVendaRest){
		$sql = "
    		UPDATE 
					VENDAREST 

		   	SET 
					IDSINCMSDE  = 'N'
			
		 	WHERE CDFILIAL    = :CDFILIAL
		    AND NRVENDAREST = :NRVENDAREST
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $cdFilial);
		$stmt->bindValue("NRVENDAREST", $nrVendaRest);
		$result = $stmt->executeQuery();
		return $result;
	}

	public function getOrderStatus($cdFilial, $nrVendaRest, $nrComanda){
		$sql = "
		SELECT 
			IDSTCOMANDA
		  
		FROM 
			COMANDAVEN
	  
	  	WHERE CDFILIAL     = :CDFILIAL
		  AND NRVENDAREST  = :NRVENDAREST
		  AND NRCOMANDA    = :NRCOMANDA
		";
		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $cdFilial);
		$stmt->bindValue("NRVENDAREST", $nrVendaRest);
		$stmt->bindValue("NRCOMANDA", $nrComanda);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getBranchList() {
		$sql = "
		SELECT DISTINCT F.CDFILIAL,
		       F.CDFILIAL||' - '||F.NMFILIAL AS LABELFILIAL
		  
		  FROM FILIAL F 
		  
		  JOIN VENDAREST V
			ON F.CDFILIAL = V.CDFILIAL
		ORDER BY CDFILIAL 
		";

		$stmt = $this->connection->prepare($sql);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getOrderNumber($search) {
		$sql = "
		SELECT DISTINCT C.NRCOMANDA,
		      F.NMFILIAL ||' - '|| C.NRCOMANDA AS CODIGOPEDIDO

  		  FROM COMANDAVEN C

  		  JOIN FILIAL F
    		ON C.CDFILIAL = F.CDFILIAL
		";

		if(!empty($search)) {
			$chrToConcat = '$$';
			$columns = ['C.NRCOMANDA', 'F.NMFILIAL'];
			$columnsToSearch = implode("||'$chrToConcat'||", $columns);

			$sql .= "WHERE (LOWER($columnsToSearch) LIKE LOWER(:SEARCH))";
			$stmt = $this->connection->prepare($sql);
			$stmt->bindValue("SEARCH", "%$search%");
		}

		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function deleteLogs($CDINTEGRACAOERR) {
		$sql = "
		UPDATE INTEGRACAOERR
		SET IDATIVO = 'N'
		WHERE CDINTEGRACAOERR = :CDINTEGRACAOERR
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDINTEGRACAOERR", $CDINTEGRACAOERR);
		$stmt->executeQuery();
	}

	public function getConsumers($searchTerm) {
		$sql = "
			SELECT DISTINCT
				NVL(C.DSCONSUMIDOR, CONS.NMCONSUMIDOR) AS CONSUMIDOR			
			FROM VENDAREST V

			JOIN CONSUMIDOR CONS
				ON V.CDCLIENTE     = CONS.CDCLIENTE
				AND V.CDCONSUMIDOR = CONS.CDCONSUMIDOR

			JOIN COMANDAVEN C
				ON V.CDFILIAL    = C.CDFILIAL
				AND V.NRVENDAREST = C.NRVENDAREST

			WHERE
				UPPER(CONS.NMCONSUMIDOR) LIKE '%' || UPPER(:SEARCH) || '%'
				OR UPPER(C.DSCONSUMIDOR) LIKE '%' || UPPER(:SEARCH) || '%'
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("SEARCH", $searchTerm);
		$result = $stmt->executeQuery();
		return $result->fetchAllAssociative();
	}

	public function selectTableInteg() {
		$sql = "
		SELECT NMINTEGRACAO, CDINTEGRACAO
		FROM INTEGRACAO
		";

		$stmt = $this->connection->prepare($sql);

		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function selectTableFilial() {
		$sql = "
		SELECT CDFILIAL, NMFILIAL 
		FROM FILIAL
		ORDER BY CDFILIAL
		";

		$stmt = $this->connection->prepare($sql);

		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getLogDetails($cdIntegracaoErr) {
		$sql = "
			SELECT 
				DSARQPED
			FROM
				INTEGRACAOERR
			WHERE
				CDINTEGRACAOERR = :CDINTEGRACAOERR   
		";
	
		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDINTEGRACAOERR", $cdIntegracaoErr);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getOrderDetails($params) {
		$sql = "
			SELECT
				OP.NMOPERADOR,
				VD.NMRAZSOCVEN
			FROM VENDEDOR VD

		JOIN OPERADOR OP
			ON VD.CDOPERADOR = OP.CDOPERADOR			

			WHERE OP.CDOPERADOR = :CDOPERADOR
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDOPERADOR", $params['CDOPERADOR']);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getOrderAddress($params) {
		$sql = "
			SELECT  
				C.CDPAIS, C.SGESTADO, C.CDMUNICIPIO, C.CDBAIRRO, C.DSENDECONSCOMAN, C.DSCOMPLENDCOCOM, 
			  C.DSREFENDCONSCOM, C.NRCEPCONSCOMAND, NVL(C.NRENDECONSCOMAN, '') AS NRENDERECO, 
			  M.NMMUNICIPIO, C.DSBAIRRO AS NMBAIRRO, P.NMPAIS, E.NMESTADO
	
		  	FROM COMANDAVEN C 
    
     	LEFT JOIN PAIS P
				ON P.CDPAIS	= C.CDPAIS
	 
			LEFT JOIN ESTADO E
	 	    ON E.SGESTADO	= C.SGESTADO
		   	AND E.CDPAIS	= C.CDPAIS
	
	 		LEFT JOIN MUNICIPIO M
				ON M.CDMUNICIPIO = C.CDMUNICIPIO
		   	AND M.SGESTADO   = C.SGESTADO
		   	AND M.CDPAIS     = C.CDPAIS
	 
	 		LEFT JOIN BAIRRO B
				ON B.CDBAIRRO     = C.CDBAIRRO
	      AND B.CDMUNICIPIO = C.CDMUNICIPIO
		   	AND B.SGESTADO    = C.SGESTADO
		   	AND B.CDPAIS      = C.CDPAIS
	
	     WHERE C.CDFILIAL  = :CDFILIAL
		   	AND C.NRCOMANDA   = :NRCOMANDA
	";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("NRCOMANDA", $params['NRCOMANDA']);
		$stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getPaymentMethods($params) {
		$sql = "
			SELECT M.IDTIPOMOVIVEDLV, M.VRMOVIVENDDLV, T.NMTIPORECE, T.CDTIPORECE
				
			FROM VENDAREST V 
			
			JOIN MOVCAIXADLV M
			ON V.CDFILIAL = M.CDFILIAL
			AND V.NRVENDAREST = M.NRVENDAREST
			AND V.CDCLIENTE = M.CDCLIENTE
			
			JOIN TIPORECE T
				ON T.CDTIPORECE = M.CDTIPORECE
		
		WHERE V.CDFILIAL    = :CDFILIAL
			AND V.NRVENDAREST = :NRVENDAREST
		
		ORDER BY NRSEQMOVDLV
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
		$stmt->bindValue("NRVENDAREST", $params['NRVENDAREST']);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getOrderItemsRepo($params) {
		$sql = "
    SELECT IT.CDPRODUTO, PR.NMPRODUTO, NVL(PR.DSPRODVENDA, '') AS DESCRIPTION, '' AS CDPRODPROMOCAO, 
			   IT.VRPRECCOMVEN , IT.QTPRODCOMVEN , IT.VRDESCCOMVEN, IT.VRACRCOMVEN, IT.NRINSCRCONS, IT.NRPRODCOMVEN,
			   IT.NRSEQPRODCOM, IT.CDFILIAL,	IT.NRVENDAREST, IT.NRCOMANDA

		  FROM ITCOMANDAVEN IT
		  JOIN PRODUTO PR
		    ON IT.CDPRODUTO = PR.CDPRODUTO

     LEFT JOIN OBSITCOMANDAVEN OBS
            ON OBS.CDFILIAL        = IT.CDFILIAL
           AND OBS.NRVENDAREST     = IT.NRVENDAREST
           AND OBS.NRCOMANDA       = IT.NRCOMANDA
           AND OBS.NRPRODCOMVENOBS = IT.NRPRODCOMVEN

				WHERE IT.CDFILIAL 		= :CDFILIAL
					 AND IT.NRVENDAREST = :NRVENDAREST
					 AND IT.NRCOMANDA 	= :NRCOMANDA
					 AND IT.CDPRODPROMOCAO 	 IS NULL
					 AND OBS.NRPRODCOMVENOBS IS NULL
		";
		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
		$stmt->bindValue("NRVENDAREST", $params['NRVENDAREST']);
		$stmt->bindValue("NRCOMANDA", $params['NRCOMANDA']);
		$result = $stmt->executeQuery();
		return $result->fetchAllAssociative();
	}

	public function getOrderCombos($params) {
		$sql = "
			SELECT IT.CDPRODPROMOCAO AS CDPRODUTO, IT.CDPRODPROMOCAO, PR.NMPRODUTO,
				IT.NRSEQPRODCOM, 1 AS QTPRODCOMVEN, SUM(IT.VRPRECCOMVEN * IT.QTPRODCOMVEN) VRPRECCOMVEN,
			  SUM(IT.VRDESCCOMVEN) VRDESCCOMVEN, SUM(IT.VRACRCOMVEN) VRACRCOMVEN,
				IT.CDFILIAL,	IT.NRVENDAREST, IT.NRCOMANDA
			FROM ITCOMANDAVEN IT

			JOIN PRODUTO PR
				ON IT.CDPRODPROMOCAO = PR.CDPRODUTO

			WHERE IT.CDFILIAL    = :CDFILIAL
				AND IT.NRVENDAREST = :NRVENDAREST
				AND IT.NRCOMANDA   = :NRCOMANDA
				AND IT.CDPRODPROMOCAO IS NOT NULL
				AND IT.NRSEQPRODCOM IS NOT NULL

		GROUP BY IT.CDFILIAL, IT.NRVENDAREST, IT.NRCOMANDA, IT.CDPRODPROMOCAO, PR.NMPRODUTO, IT.NRSEQPRODCOM
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
		$stmt->bindValue("NRVENDAREST", $params['NRVENDAREST']);
		$stmt->bindValue("NRCOMANDA", $params['NRCOMANDA']);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getSubItens($params) {
		$sql = "
			SELECT IT.CDPRODUTO, PR.NMPRODUTO, NVL(PR.DSPRODVENDA, '') AS DESCRIPTION,
				IT.VRPRECCOMVEN , IT.QTPRODCOMVEN , IT.VRDESCCOMVEN, IT.VRACRCOMVEN,
				IT.NRINSCRCONS, IT.NRPRODCOMVEN, IT.NRSEQPRODCOM
			FROM ITCOMANDAVEN IT

			JOIN PRODUTO PR
				ON IT.CDPRODUTO = PR.CDPRODUTO

			LEFT JOIN OBSITCOMANDAVEN OBS
				ON OBS.CDFILIAL         = IT.CDFILIAL
				AND OBS.NRVENDAREST     = IT.NRVENDAREST
				AND OBS.NRCOMANDA       = IT.NRCOMANDA
				AND OBS.NRPRODCOMVENOBS = IT.NRPRODCOMVEN
	
			WHERE IT.CDFILIAL       = :CDFILIAL
				AND IT.NRVENDAREST    = :NRVENDAREST
				AND IT.NRCOMANDA      = :NRCOMANDA
				AND IT.CDPRODPROMOCAO = :CDPRODPROMOCAO
				AND IT.NRSEQPRODCOM   = :NRSEQPRODCOM
				AND OBS.NRPRODCOMVENOBS IS NULL
		";
		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
		$stmt->bindValue("NRVENDAREST", $params['NRVENDAREST']);
		$stmt->bindValue("NRCOMANDA", $params['NRCOMANDA']);
		$stmt->bindValue("CDPRODPROMOCAO", $params['CDPRODPROMOCAO']);
		$stmt->bindValue("NRSEQPRODCOM", $params['NRSEQPRODCOM']);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getItemObservation($params) {
		$sql = "
			SELECT DSOCORR, CDOCORR, CDGRPOCOR, (VRPRECCOMVEN*QTPRODCOMVENOBS) AS VRPRECCOMVEN,
				CDFILIAL, NRVENDAREST, NRCOMANDA, NRPRODCOMVEN, QTPRODCOMVENOBS
				FROM (
					SELECT NVL(OC.DSAPELIDOOBS, OC.DSOCORR) DSOCORR, OC.CDOCORR, OC.CDGRPOCOR, 0 VRPRECCOMVEN,
							OBIT.CDFILIAL, OBIT.NRVENDAREST, OBIT.NRCOMANDA, OBIT.NRPRODCOMVEN, OBIT.QTPRODCOMVENOBS

					FROM OBSITCOMANDAVEN OBIT
						JOIN OCORRENCIA OC
							ON OBIT.CDGRPOCOR = OC.CDGRPOCOR
							AND OBIT.CDOCORR   = OC.CDOCORR 	  
			
					WHERE OC.CDPRODUTO IS NULL

					UNION

					SELECT NVL(OC.DSAPELIDOOBS, OC.DSOCORR) DSOCORR, OC.CDOCORR, OC.CDGRPOCOR, 
							NVL(IT.VRPRECCOMVEN, 0) VRPRECCOMVEN, OBIT.CDFILIAL, OBIT.NRVENDAREST, 
							OBIT.NRCOMANDA, OBIT.NRPRODCOMVEN, OBIT.QTPRODCOMVENOBS

					FROM OBSITCOMANDAVEN OBIT

					JOIN OCORRENCIA OC
						ON OBIT.CDGRPOCOR = OC.CDGRPOCOR
						AND OBIT.CDOCORR   = OC.CDOCORR	
					LEFT JOIN (SELECT DISTINCT CDFILIAL, NRCOMANDA, NRVENDAREST, CDPRODUTO, VRPRECCOMVEN, NRPRODCOMVEN
												FROM ITCOMANDAVEN
								)IT
							ON IT.NRCOMANDA   = OBIT.NRCOMANDA
						AND IT.NRVENDAREST  = OBIT.NRVENDAREST
						AND IT.CDFILIAL     = OBIT.CDFILIAL 	
						AND IT.NRPRODCOMVEN = OBIT.NRPRODCOMVENOBS
				
					WHERE OC.CDPRODUTO IS NOT NULL	
						AND OC.IDCONTROLAOBS = 'A'
				)

				WHERE NRCOMANDA    = :NRCOMANDA
					AND NRVENDAREST  = :NRVENDAREST
					AND CDFILIAL     = :CDFILIAL
					AND NRPRODCOMVEN = :NRPRODCOMVEN
		";
		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
		$stmt->bindValue("NRVENDAREST", $params['NRVENDAREST']);
		$stmt->bindValue("NRCOMANDA", $params['NRCOMANDA']);
		$stmt->bindValue("NRPRODCOMVEN", $params['NRPRODCOMVEN']);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function getOtherItemObservation($params) {
		$sql = "
			SELECT TXPRODCOMVEN AS DSOCORR, '' CDOCORR, '' CDGRPOCOR,
				0 AS VRPRECCOMVEN, CDFILIAL, NRVENDAREST, NRCOMANDA,
				NRPRODCOMVEN, 1 AS QTPRODCOMVENOBS

			FROM ITCOMANDAVEN

			WHERE NRCOMANDA    = :NRCOMANDA
				AND NRVENDAREST  = :NRVENDAREST
				AND CDFILIAL     = :CDFILIAL
				AND NRPRODCOMVEN = :NRPRODCOMVEN
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $params['CDFILIAL']);
		$stmt->bindValue("NRVENDAREST", $params['NRVENDAREST']);
		$stmt->bindValue("NRCOMANDA", $params['NRCOMANDA']);
		$stmt->bindValue("NRPRODCOMVEN", $params['NRPRODCOMVEN']);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function dashboard($dtInicAberMesa, $dtFimAberMesa) {
		$sql = "
			SELECT
				NVL(C.IDORGCMDVENDA, 'DLV_OUT')      AS IDORGCMDVENDA,
				(CASE TO_CHAR(C.IDRETBALLOJA) 
					WHEN 'S' THEN 'RETIRAR NO BALCÃO'
					WHEN 'N' THEN 'DELIVERY'
					WHEN 'C' THEN 'CONSUMO NO LOCAL'
					ELSE 'OUTROS' END) AS TOGO,
				(IT.VRTOTAL + C.VRACRCOMANDA) VRPEDIDO,
				TO_CHAR(V.DTHRABERMESA, 'DD/MM/YYYY HH24:MI:SS') AS DTHRABERMESA,
				C.IDSTCOMANDA	

			FROM VENDAREST V
				JOIN COMANDAVEN C
					ON V.CDFILIAL    = C.CDFILIAL
					AND V.NRVENDAREST = C.NRVENDAREST

					JOIN LOJA L
                        ON L.CDFILIAL = C.CDFILIAL
                         AND L.CDLOJA = C.CDLOJA

				JOIN (SELECT CDFILIAL, NRCOMANDA, 
					NRVENDAREST, SUM((QTPRODCOMVEN*VRPRECCOMVEN) - VRDESCCOMVEN + VRACRCOMVEN) AS VRTOTAL,
					SUM(QTPRODCOMVEN*VRPRECCOMVEN) AS VRTOTALPRODUTOS, SUM(VRDESCCOMVEN) AS VRDESCOMANDA,
					SUM(QTPRODCOMVEN) AS QTDPROD
		 		FROM ITCOMANDAVEN
	 				GROUP BY CDFILIAL, NRCOMANDA, NRVENDAREST) IT
						ON IT.CDFILIAL     = C.CDFILIAL
						AND IT.NRVENDAREST = C.NRVENDAREST
						AND IT.NRCOMANDA   = C.NRCOMANDA

			WHERE V.DTHRABERMESA BETWEEN (TO_DATE(:DTINICABERMESA, 'DD/MM/YYYY HH24:MI:SS')) AND (TO_DATE(:DTFIMABERMESA, 'DD/MM/YYYY HH24:MI:SS'))
			ORDER BY V.DTHRABERMESA DESC
		";
		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("DTINICABERMESA", $dtInicAberMesa);
		$stmt->bindValue("DTFIMABERMESA", $dtFimAberMesa);
		$result = $stmt->executeQuery();
		
		return $result->fetchAllAssociative();
	}

	public function forwardOrderComandaven($cdFilial, $nrComanda, $nrVendaRest) {
		$sql = "
			UPDATE COMANDAVEN

			SET IDSINCAGENDA = 'S', 
		 		IDSTCOMANDA     = '3'


	  		WHERE CDFILIAL     = :CDFILIAL
				AND NRCOMANDA    = :NRCOMANDA
				AND NRVENDAREST  = :NRVENDAREST
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $cdFilial);
		$stmt->bindValue("NRCOMANDA", $nrComanda);
		$stmt->bindValue("NRVENDAREST", $nrVendaRest);
		$stmt->executeQuery();
	}

	public function forwardOrderVendarest($cdFilial, $nrVendaRest) {
		$sql = "
			UPDATE VENDAREST
			SET DTHRABERMESA = SYSDATE
		  	WHERE CDFILIAL     = :CDFILIAL
				AND NRVENDAREST  = :NRVENDAREST
 
		";

		$stmt = $this->connection->prepare($sql);
		$stmt->bindValue("CDFILIAL", $cdFilial);
		$stmt->bindValue("NRVENDAREST", $nrVendaRest);
		$stmt->executeQuery();
	}
}